@@ -3,11 +3,14 @@
 
   author: Henryk Richter
 
-  last update: Tue May 7 2002 
+  last update: 20-May-2019
 
   purpose: just an addon toy for gkrellm
 
   changelog:
+  0.9 - changed getcpu() naming to avoid clashes
+        with Linux syscall
+
   0.5 - port to GKrellm 2.0 (thanks to Bill Nalen)
       - port to Win32 (thanks to Bill Nalen)
       - kept the code downwards compatible 
@@ -128,7 +131,7 @@ static void flynn_load_config (gchar *arg)
 }
 
 /* get current cpu usage */
-int getcpu( void )
+int flynn_getcpu( void )
 {
 	float scale_factor = 1;
 #if 0
@@ -246,7 +249,7 @@ static void update_plugin()
 		if( flynn_look < 0 ) flynn_look = 0;
 		if( flynn_look >= F_LOOKSTATES ) flynn_look = F_LOOKSTATES-1;
 	   }
-		percent = getcpu();
+		percent = flynn_getcpu();
 
 		image_number = flynn_look * F_TORTURES + (F_TORTURES * percent / 100);
 
